==> netflux-0.4.2.tgz: package/karma.conf.js <==
// Karma configuration
// Generated on Tue Dec 22 2015 18:29:31 GMT+0100 (CET)

module.exports = function(config) {
  config.set({

    // base path that will be used to resolve all patterns (eg. files, exclude)
    basePath: '',


    // frameworks to use
    // available frameworks: https://npmjs.org/browse/keyword/karma-adapter
    frameworks: ['jspm', 'jasmine'],


    // jspm parameters
    jspm: {
      config: 'config.js',
      loadFiles: ['test/**/*test.js'],
      serveFiles: ['src/**/*.js', 'dist/netflux.js']
    },
    proxies: {
      '/src/': '/base/src/',
      '/dist/': '/base/dist/',
      '/test/': '/base/test/',
      '/jspm_packages/': '/base/jspm_packages/'
    },


    // list of files / patterns to load in the browser
    files: [
      'dist/netflux.js',
      'node_modules/babel-polyfill/dist/polyfill.js'
    ],


    // list of files to exclude
    exclude: [
    ],


    // preprocess matching files before serving them to the browser
    // available preprocessors: https://npmjs.org/browse/keyword/karma-preprocessor
    preprocessors: {
      'src/**/*.js': ['babel', 'sourcemap', 'coverage']
    },
    babelPreprocessor: {
      options: {
        presets: ['es2015'],
        sourceMap: 'inline'
      },
      sourceFileName: function (file) {
        return file.originalPath;
      }
    },


    // test results reporter to use
    // possible values: 'dots', 'progress'
    // available reporters: https://npmjs.org/browse/keyword/karma-reporter
    reporters: ['progress', 'coverage'],
    coverageReporter: {
      instrumenters: {isparta: require('isparta')},
      instrumenter: {'src/*.js': 'isparta'},
      reporters: [
        {type: 'html'},
        {type: 'text'},
        {type: 'lcovonly', subdir: '.'}
      ]
    },


    // web server port
    port: 9876,


    // enable / disable colors in the output (reporters and logs)
    colors: true,


    // level of logging
    // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
    logLevel: config.LOG_INFO,


    // enable / disable watching file and executing tests whenever any file changes
    autoWatch: false,


    // start these browsers
    // available browser launchers: https://npmjs.org/browse/keyword/karma-launcher
    browsers: ['Chrome', 'Firefox'],


    // Continuous Integration mode
    // if true, Karma captures browsers, runs the tests and exits
    singleRun: true,

    // Concurrency level
    // how many browser should be started simultanous
    concurrency: Infinity
  })
}

==> netflux-0.4.4.tgz: package/karma.conf.js <==
// Karma configuration
// Generated on Tue Dec 22 2015 18:29:31 GMT+0100 (CET)

module.exports = function(config) {
  config.set({

    // base path that will be used to resolve all patterns (eg. files, exclude)
    basePath: '',


    // frameworks to use
    // available frameworks: https://npmjs.org/browse/keyword/karma-adapter
    frameworks: ['jspm', 'jasmine'],


    // jspm parameters
    jspm: {
      config: 'config.js',
      loadFiles: ['test/**/*test.js'],
      serveFiles: ['src/**/*.js', 'dist/netflux.es2015.js']
    },
    proxies: {
      '/src/': '/base/src/',
      '/dist/': '/base/dist/',
      '/test/': '/base/test/',
      '/jspm_packages/': '/base/jspm_packages/'
    },


    // list of files / patterns to load in the browser
    files: [
      'dist/netflux.es2015.js',
      'node_modules/babel-polyfill/dist/polyfill.js'
    ],


    // list of files to exclude
    exclude: [
    ],


    // preprocess matching files before serving them to the browser
    // available preprocessors: https://npmjs.org/browse/keyword/karma-preprocessor
    preprocessors: {
      'src/**/*.js': ['babel', 'sourcemap', 'coverage']
    },
    babelPreprocessor: {
      options: {
        presets: ['es2015'],
        sourceMap: 'inline'
      },
      sourceFileName: function (file) {
        return file.originalPath;
      }
    },


    // test results reporter to use
    // possible values: 'dots', 'progress'
    // available reporters: https://npmjs.org/browse/keyword/karma-reporter
    reporters: ['progress', 'coverage'],
    coverageReporter: {
      instrumenters: {isparta: require('isparta')},
      instrumenter: {'src/*.js': 'isparta'},
      reporters: [
        {type: 'html'},
        {type: 'text'},
        {type: 'lcovonly', subdir: '.'}
      ]
    },


    // web server port
    port: 9876,


    // enable / disable colors in the output (reporters and logs)
    colors: true,


    // level of logging
    // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
    logLevel: config.LOG_INFO,


    // enable / disable watching file and executing tests whenever any file changes
    autoWatch: false,


    // start these browsers
    // available browser launchers: https://npmjs.org/browse/keyword/karma-launcher
    browsers: ['Chrome', 'Firefox'],


    // Continuous Integration mode
    // if true, Karma captures browsers, runs the tests and exits
    singleRun: true,

    // Concurrency level
    // how many browser should be started simultanous
    concurrency: Infinity
  })
}
